PatrolLogWriter class
Constructors
-
PatrolLogWriter({Map<
String, dynamic> config = const {}})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
log(
Entry entry) → void -
Logs an
entryto the stream. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
) → void - Writes the entries to the console.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited