StepEntry class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

StepEntry({required String action, required StepEntryStatus status, Map<String, dynamic>? data, DateTime? timestamp})
StepEntry.fromJson(Map<String, dynamic> json)
factory

Properties

action String
final
data Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status StepEntryStatus
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
timestamp DateTime
finalinherited
type EntryType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pretty({int? number}) String
override
printIndex(int? number) String
Returns the index of the step with the correct number of spaces, to format the output.
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited