AnsiCodes class

Constructors

AnsiCodes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

blue String
getter/setter pair
cyan String
getter/setter pair
gray String
getter/setter pair
green String
getter/setter pair
lightBlue String
getter/setter pair
magenta String
getter/setter pair
orange String
getter/setter pair
red String
getter/setter pair
yellow String
getter/setter pair

Static Methods

color(String color) String

Constants

bold → const String
[1m - Set text to bold.
escape → const String
This is the Unicode escape sequence for the ASCII escape character (ESC).
reset → const String
[0m - Reset all styles.