TestEntry class
Constructors
- TestEntry({required String name, required TestEntryStatus status, DateTime? timestamp, String? error})
-
TestEntry.fromJson(Map<
String, dynamic> json) -
factory
Properties
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFinished → bool
-
Returns
trueif the test is finished, successfully or with a failure.no setter - name → String
-
final
- nameWithPath → String
-
no setter
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → TestEntryStatus
-
final
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited - timestamp → DateTime
-
finalinherited
- type → EntryType
-
finalinherited
Methods
-
executionTime(
DateTime start) → Duration -
Returns the execution time between
startand TestEntry timestamp. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pretty(
) → String -
override
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited